==> fundus-0.4.4-py3-none-any.whl: fundus/publishers/uk/daily_mail.py <==
import datetime
from typing import List, Optional

from lxml.cssselect import CSSSelector

from fundus.parser import ArticleBody, BaseParser, ParserProxy, attribute
from fundus.parser.utility import (
    extract_article_body_with_selector,
    generic_author_parsing,
    generic_date_parsing,
    generic_topic_parsing,
)


class DailyMailParser(ParserProxy):
    class V1(BaseParser):
        _paragraph_selector = CSSSelector("div[itemprop='articleBody'] > p")
        _summary_selector = CSSSelector("#js-article-text > h1")

        @attribute
        def body(self) -> ArticleBody:
            return extract_article_body_with_selector(
                self.precomputed.doc,
                paragraph_selector=self._paragraph_selector,
            )

        @attribute
        def publishing_date(self) -> Optional[datetime.datetime]:
            return generic_date_parsing(self.precomputed.ld.bf_search("datePublished"))

        @attribute
        def authors(self) -> List[str]:
            return generic_author_parsing(self.precomputed.ld.bf_search("author"))

        @attribute
        def title(self) -> Optional[str]:
            return self.precomputed.meta.get("og:title")

        @attribute
        def topics(self) -> List[str]:
            filtered_topics = []
            for topic in generic_topic_parsing(self.precomputed.meta.get("keywords")):
                if topic.casefold() != topic:
                    filtered_topics.append(topic)
            return filtered_topics

==> fundus-0.4.6-py3-none-any.whl: fundus/publishers/uk/daily_mail.py <==
import datetime
from typing import List, Optional

from lxml.cssselect import CSSSelector

from fundus.parser import ArticleBody, BaseParser, ParserProxy, attribute
from fundus.parser.utility import (
    extract_article_body_with_selector,
    generic_author_parsing,
    generic_date_parsing,
    generic_topic_parsing,
)


class DailyMailParser(ParserProxy):
    class V1(BaseParser):
        _paragraph_selector = CSSSelector("div[itemprop='articleBody'] > p")
        _summary_selector = CSSSelector("#js-article-text > h1")

        @attribute
        def body(self) -> Optional[ArticleBody]:
            return extract_article_body_with_selector(
                self.precomputed.doc,
                paragraph_selector=self._paragraph_selector,
            )

        @attribute
        def publishing_date(self) -> Optional[datetime.datetime]:
            return generic_date_parsing(self.precomputed.ld.bf_search("datePublished"))

        @attribute
        def authors(self) -> List[str]:
            return generic_author_parsing(self.precomputed.ld.bf_search("author"))

        @attribute
        def title(self) -> Optional[str]:
            return self.precomputed.meta.get("og:title")

        @attribute
        def topics(self) -> List[str]:
            filtered_topics = []
            for topic in generic_topic_parsing(self.precomputed.meta.get("keywords")):
                if topic.casefold() != topic:
                    filtered_topics.append(topic)
            return filtered_topics
